@@ -155,12 +155,14 @@ class Access extends LDAPUtility implements IUserTools {
 
 	/**
 	 * reads a given attribute for an LDAP record identified by a DN
+	 *
 	 * @param string $dn the record in question
 	 * @param string $attr the attribute that shall be retrieved
 	 *        if empty, just check the record's existence
 	 * @param string $filter
 	 * @return array|false an array of values on success or an empty
 	 *          array if $attr is empty, false otherwise
+	 * @throws ServerNotAvailableException
 	 */
 	public function readAttribute($dn, $attr, $filter = 'objectClass=*') {
 		if(!$this->checkConnection()) {
@@ -184,46 +186,147 @@ class Access extends LDAPUtility implements IUserTools {
 		// 0 won't result in replies, small numbers may leave out groups
 		// (cf. #12306), 500 is default for paging and should work everywhere.
 		$maxResults = $pagingSize > 20 ? $pagingSize : 500;
-		$this->initPagedSearch($filter, array($dn), array($attr), $maxResults, 0);
+		$attr = mb_strtolower($attr, 'UTF-8');
+		// the actual read attribute later may contain parameters on a ranged
+		// request, e.g. member;range=99-199. Depends on server reply.
+		$attrToRead = $attr;
+
+		$values = [];
+		$isRangeRequest = false;
+		do {
+			$result = $this->executeRead($cr, $dn, $attrToRead, $filter, $maxResults);
+			if(is_bool($result)) {
+				// when an exists request was run and it was successful, an empty
+				// array must be returned
+				return $result ? [] : false;
+			}
+
+			if (!$isRangeRequest) {
+				$values = $this->extractAttributeValuesFromResult($result, $attr);
+				if (!empty($values)) {
+					return $values;
+				}
+			}
+
+			$isRangeRequest = false;
+			$result = $this->extractRangeData($result, $attr);
+			if (!empty($result)) {
+				$normalizedResult = $this->extractAttributeValuesFromResult(
+					[ $attr => $result['values'] ],
+					$attr
+				);
+				$values = array_merge($values, $normalizedResult);
+
+				if($result['rangeHigh'] === '*') {
+					// when server replies with * as high range value, there are
+					// no more results left
+					return $values;
+				} else {
+					$low  = $result['rangeHigh'] + 1;
+					$attrToRead = $result['attributeName'] . ';range=' . $low . '-*';
+					$isRangeRequest = true;
+				}
+			}
+		} while($isRangeRequest);
+
+		\OCP\Util::writeLog('user_ldap', 'Requested attribute '.$attr.' not found for '.$dn, \OCP\Util::DEBUG);
+		return false;
+	}
+
+	/**
+	 * Runs an read operation against LDAP
+	 *
+	 * @param resource $cr the LDAP connection
+	 * @param string $dn
+	 * @param string $attribute
+	 * @param string $filter
+	 * @param int $maxResults
+	 * @return array|bool false if there was any error, true if an exists check
+	 *                    was performed and the requested DN found, array with the
+	 *                    returned data on a successful usual operation
+	 * @throws ServerNotAvailableException
+	 */
+	public function executeRead($cr, $dn, $attribute, $filter, $maxResults) {
+		$this->initPagedSearch($filter, array($dn), array($attribute), $maxResults, 0);
 		$dn = $this->helper->DNasBaseParameter($dn);
-		$rr = @$this->invokeLDAPMethod('read', $cr, $dn, $filter, array($attr));
-		if(!$this->ldap->isResource($rr)) {
-			if ($attr !== '') {
+		$rr = @$this->invokeLDAPMethod('read', $cr, $dn, $filter, array($attribute));
+		if (!$this->ldap->isResource($rr)) {
+			if ($attribute !== '') {
 				//do not throw this message on userExists check, irritates
-				\OCP\Util::writeLog('user_ldap', 'readAttribute failed for DN '.$dn, \OCP\Util::DEBUG);
+				\OCP\Util::writeLog('user_ldap', 'readAttribute failed for DN ' . $dn, \OCP\Util::DEBUG);
 			}
 			//in case an error occurs , e.g. object does not exist
 			return false;
 		}
-		if ($attr === '' && ($filter === 'objectclass=*' || $this->invokeLDAPMethod('countEntries', $cr, $rr) === 1)) {
-			\OCP\Util::writeLog('user_ldap', 'readAttribute: '.$dn.' found', \OCP\Util::DEBUG);
-			return array();
+		if ($attribute === '' && ($filter === 'objectclass=*' || $this->invokeLDAPMethod('countEntries', $cr, $rr) === 1)) {
+			\OCP\Util::writeLog('user_ldap', 'readAttribute: ' . $dn . ' found', \OCP\Util::DEBUG);
+			return true;
 		}
 		$er = $this->invokeLDAPMethod('firstEntry', $cr, $rr);
-		if(!$this->ldap->isResource($er)) {
+		if (!$this->ldap->isResource($er)) {
 			//did not match the filter, return false
 			return false;
 		}
 		//LDAP attributes are not case sensitive
 		$result = \OCP\Util::mb_array_change_key_case(
 			$this->invokeLDAPMethod('getAttributes', $cr, $er), MB_CASE_LOWER, 'UTF-8');
-		$attr = mb_strtolower($attr, 'UTF-8');
 
-		if(isset($result[$attr]) && $result[$attr]['count'] > 0) {
-			$values = array();
-			for($i=0;$i<$result[$attr]['count'];$i++) {
-				if($this->resemblesDN($attr)) {
-					$values[] = $this->helper->sanitizeDN($result[$attr][$i]);
-				} elseif(strtolower($attr) === 'objectguid' || strtolower($attr) === 'guid') {
-					$values[] = $this->convertObjectGUID2Str($result[$attr][$i]);
+		return $result;
+	}
+
+	/**
+	 * Normalizes a result grom getAttributes(), i.e. handles DNs and binary
+	 * data if present.
+	 *
+	 * @param array $result from ILDAPWrapper::getAttributes()
+	 * @param string $attribute the attribute name that was read
+	 * @return string[]
+	 */
+	public function extractAttributeValuesFromResult($result, $attribute) {
+		$values = [];
+		if(isset($result[$attribute]) && $result[$attribute]['count'] > 0) {
+			$lowercaseAttribute = strtolower($attribute);
+			for($i=0;$i<$result[$attribute]['count'];$i++) {
+				if($this->resemblesDN($attribute)) {
+					$values[] = $this->helper->sanitizeDN($result[$attribute][$i]);
+				} elseif($lowercaseAttribute === 'objectguid' || $lowercaseAttribute === 'guid') {
+					$values[] = $this->convertObjectGUID2Str($result[$attribute][$i]);
 				} else {
-					$values[] = $result[$attr][$i];
+					$values[] = $result[$attribute][$i];
 				}
 			}
-			return $values;
 		}
-		\OCP\Util::writeLog('user_ldap', 'Requested attribute '.$attr.' not found for '.$dn, \OCP\Util::DEBUG);
-		return false;
+		return $values;
+	}
+
+	/**
+	 * Attempts to find ranged data in a getAttribute results and extracts the
+	 * returned values as well as information on the range and full attribute
+	 * name for further processing.
+	 *
+	 * @param array $result from ILDAPWrapper::getAttributes()
+	 * @param string $attribute the attribute name that was read. Without ";range=…"
+	 * @return array If a range was detected with keys 'values', 'attributeName',
+	 *               'attributeFull' and 'rangeHigh', otherwise empty.
+	 */
+	public function extractRangeData($result, $attribute) {
+		$keys = array_keys($result);
+		foreach($keys as $key) {
+			if($key !== $attribute && strpos($key, $attribute) === 0) {
+				$queryData = explode(';', $key);
+				if(strpos($queryData[1], 'range=') === 0) {
+					$high = substr($queryData[1], 1 + strpos($queryData[1], '-'));
+					$data = [
+						'values' => $result[$key],
+						'attributeName' => $queryData[0],
+						'attributeFull' => $key,
+						'rangeHigh' => $high,
+					];
+					return $data;
+				}
+			}
+		}
+		return [];
 	}
 	
 	/**
@@ -246,7 +349,7 @@ class Access extends LDAPUtility implements IUserTools {
 			return false;
 		}
 		try {
-			return $this->invokeLDAPMethod('modReplace', $cr, $userDN, $password);
+			return @$this->invokeLDAPMethod('modReplace', $cr, $userDN, $password);
 		} catch(ConstraintViolationException $e) {
 			throw new HintException('Password change rejected.', \OC::$server->getL10N('user_ldap')->t('Password change rejected. Hint: ').$e->getMessage(), $e->getCode());
 		}
@@ -308,8 +411,8 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * returns the LDAP DN for the given internal ownCloud name of the group
-	 * @param string $name the ownCloud name in question
+	 * returns the LDAP DN for the given internal Nextcloud name of the group
+	 * @param string $name the Nextcloud name in question
 	 * @return string|false LDAP DN on success, otherwise false
 	 */
 	public function groupname2dn($name) {
@@ -317,8 +420,8 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * returns the LDAP DN for the given internal ownCloud name of the user
-	 * @param string $name the ownCloud name in question
+	 * returns the LDAP DN for the given internal Nextcloud name of the user
+	 * @param string $name the Nextcloud name in question
 	 * @return string|false with the LDAP DN on success, otherwise false
 	 */
 	public function username2dn($name) {
@@ -334,10 +437,10 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * returns the internal ownCloud name for the given LDAP DN of the group, false on DN outside of search DN or failure
+	 * returns the internal Nextcloud name for the given LDAP DN of the group, false on DN outside of search DN or failure
 	 * @param string $fdn the dn of the group object
 	 * @param string $ldapName optional, the display name of the object
-	 * @return string|false with the name to use in ownCloud, false on DN outside of search DN
+	 * @return string|false with the name to use in Nextcloud, false on DN outside of search DN
 	 */
 	public function dn2groupname($fdn, $ldapName = null) {
 		//To avoid bypassing the base DN settings under certain circumstances
@@ -357,6 +460,7 @@ class Access extends LDAPUtility implements IUserTools {
 	 *
 	 * @param string[] $groupDNs
 	 * @return string[]
+	 * @throws ServerNotAvailableException
 	 */
 	public function groupsMatchFilter($groupDNs) {
 		$validGroupDNs = [];
@@ -377,7 +481,7 @@ class Access extends LDAPUtility implements IUserTools {
 				continue;
 			}
 
-			$result = $this->readAttribute($dn, 'cn', $this->connection->ldapGroupFilter);
+			$result = $this->readAttribute($dn, '', $this->connection->ldapGroupFilter);
 			if(is_array($result)) {
 				$this->connection->writeToCache($cacheKey, true);
 				$validGroupDNs[] = $dn;
@@ -390,10 +494,10 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * returns the internal ownCloud name for the given LDAP DN of the user, false on DN outside of search DN or failure
+	 * returns the internal Nextcloud name for the given LDAP DN of the user, false on DN outside of search DN or failure
 	 * @param string $dn the dn of the user object
 	 * @param string $ldapName optional, the display name of the object
-	 * @return string|false with with the name to use in ownCloud
+	 * @return string|false with with the name to use in Nextcloud
 	 */
 	public function dn2username($fdn, $ldapName = null) {
 		//To avoid bypassing the base DN settings under certain circumstances
@@ -407,11 +511,11 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * returns an internal ownCloud name for the given LDAP DN, false on DN outside of search DN
+	 * returns an internal Nextcloud name for the given LDAP DN, false on DN outside of search DN
 	 * @param string $dn the dn of the user object
 	 * @param string $ldapName optional, the display name of the object
 	 * @param bool $isUser optional, whether it is a user object (otherwise group assumed)
-	 * @return string|false with with the name to use in ownCloud
+	 * @return string|false with with the name to use in Nextcloud
 	 */
 	public function dn2ocname($fdn, $ldapName = null, $isUser = true) {
 		if($isUser) {
@@ -422,7 +526,7 @@ class Access extends LDAPUtility implements IUserTools {
 			$nameAttribute = $this->connection->ldapGroupDisplayName;
 		}
 
-		//let's try to retrieve the ownCloud name from the mappings table
+		//let's try to retrieve the Nextcloud name from the mappings table
 		$ocName = $mapper->getNameByDN($fdn);
 		if(is_string($ocName)) {
 			return $ocName;
@@ -459,7 +563,19 @@ class Access extends LDAPUtility implements IUserTools {
 			} else {
 				$username = $uuid;
 			}
-			$intName = $this->sanitizeUsername($username);
+			try {
+				$intName = $this->sanitizeUsername($username);
+			} catch (\InvalidArgumentException $e) {
+				\OC::$server->getLogger()->logException($e, [
+					'app' => 'user_ldap',
+					'level' => Util::WARN,
+				]);
+				// we don't attempt to set a username here. We can go for
+				// for an alternative 4 digit random number as we would append
+				// otherwise, however it's likely not enough space in bigger
+				// setups, and most importantly: this is not intended.
+				return false;
+			}
 		} else {
 			$intName = $ldapName;
 		}
@@ -471,7 +587,7 @@ class Access extends LDAPUtility implements IUserTools {
 		$originalTTL = $this->connection->ldapCacheTTL;
 		$this->connection->setConfiguration(array('ldapCacheTTL' => 0));
 		if(($isUser && !\OCP\User::userExists($intName))
-			|| (!$isUser && !\OC_Group::groupExists($intName))) {
+			|| (!$isUser && !\OC::$server->getGroupManager()->groupExists($intName))) {
 			if($mapper->map($fdn, $intName, $uuid)) {
 				$this->connection->setConfiguration(array('ldapCacheTTL' => $originalTTL));
 				return $intName;
@@ -492,23 +608,23 @@ class Access extends LDAPUtility implements IUserTools {
 	/**
 	 * gives back the user names as they are used ownClod internally
 	 * @param array $ldapUsers as returned by fetchList()
-	 * @return array an array with the user names to use in ownCloud
+	 * @return array an array with the user names to use in Nextcloud
 	 *
 	 * gives back the user names as they are used ownClod internally
 	 */
-	public function ownCloudUserNames($ldapUsers) {
-		return $this->ldap2ownCloudNames($ldapUsers, true);
+	public function nextcloudUserNames($ldapUsers) {
+		return $this->ldap2NextcloudNames($ldapUsers, true);
 	}
 
 	/**
 	 * gives back the group names as they are used ownClod internally
 	 * @param array $ldapGroups as returned by fetchList()
-	 * @return array an array with the group names to use in ownCloud
+	 * @return array an array with the group names to use in Nextcloud
 	 *
 	 * gives back the group names as they are used ownClod internally
 	 */
-	public function ownCloudGroupNames($ldapGroups) {
-		return $this->ldap2ownCloudNames($ldapGroups, false);
+	public function nextcloudGroupNames($ldapGroups) {
+		return $this->ldap2NextcloudNames($ldapGroups, false);
 	}
 
 	/**
@@ -516,14 +632,14 @@ class Access extends LDAPUtility implements IUserTools {
 	 * @param bool $isUsers
 	 * @return array
 	 */
-	private function ldap2ownCloudNames($ldapObjects, $isUsers) {
+	private function ldap2NextcloudNames($ldapObjects, $isUsers) {
 		if($isUsers) {
 			$nameAttribute = $this->connection->ldapUserDisplayName;
 			$sndAttribute  = $this->connection->ldapUserDisplayName2;
 		} else {
 			$nameAttribute = $this->connection->ldapGroupDisplayName;
 		}
-		$ownCloudNames = array();
+		$nextcloudNames = array();
 
 		foreach($ldapObjects as $ldapObject) {
 			$nameByLDAP = null;
@@ -535,9 +651,9 @@ class Access extends LDAPUtility implements IUserTools {
 				$nameByLDAP = $ldapObject[$nameAttribute][0];
 			}
 
-			$ocName = $this->dn2ocname($ldapObject['dn'][0], $nameByLDAP, $isUsers);
-			if($ocName) {
-				$ownCloudNames[] = $ocName;
+			$ncName = $this->dn2ocname($ldapObject['dn'][0], $nameByLDAP, $isUsers);
+			if($ncName) {
+				$nextcloudNames[] = $ncName;
 				if($isUsers) {
 					//cache the user names so it does not need to be retrieved
 					//again later (e.g. sharing dialogue).
@@ -546,16 +662,16 @@ class Access extends LDAPUtility implements IUserTools {
 					}
 					$sndName = isset($ldapObject[$sndAttribute][0])
 						? $ldapObject[$sndAttribute][0] : '';
-					$this->cacheUserDisplayName($ocName, $nameByLDAP, $sndName);
+					$this->cacheUserDisplayName($ncName, $nameByLDAP, $sndName);
 				}
 			}
 		}
-		return $ownCloudNames;
+		return $nextcloudNames;
 	}
 
 	/**
 	 * caches the user display name
-	 * @param string $ocName the internal ownCloud username
+	 * @param string $ocName the internal Nextcloud username
 	 * @param string|false $home the home directory path
 	 */
 	public function cacheUserHome($ocName, $home) {
@@ -565,7 +681,7 @@ class Access extends LDAPUtility implements IUserTools {
 
 	/**
 	 * caches a user as existing
-	 * @param string $ocName the internal ownCloud username
+	 * @param string $ocName the internal Nextcloud username
 	 */
 	public function cacheUserExists($ocName) {
 		$this->connection->writeToCache('userExists'.$ocName, true);
@@ -573,21 +689,24 @@ class Access extends LDAPUtility implements IUserTools {
 
 	/**
 	 * caches the user display name
-	 * @param string $ocName the internal ownCloud username
+	 * @param string $ocName the internal Nextcloud username
 	 * @param string $displayName the display name
 	 * @param string $displayName2 the second display name
 	 */
 	public function cacheUserDisplayName($ocName, $displayName, $displayName2 = '') {
 		$user = $this->userManager->get($ocName);
+		if($user === null) {
+			return;
+		}
 		$displayName = $user->composeAndStoreDisplayName($displayName, $displayName2);
 		$cacheKeyTrunk = 'getDisplayName';
 		$this->connection->writeToCache($cacheKeyTrunk.$ocName, $displayName);
 	}
 
 	/**
-	 * creates a unique name for internal ownCloud use for users. Don't call it directly.
+	 * creates a unique name for internal Nextcloud use for users. Don't call it directly.
 	 * @param string $name the display name of the object
-	 * @return string|false with with the name to use in ownCloud or false if unsuccessful
+	 * @return string|false with with the name to use in Nextcloud or false if unsuccessful
 	 *
 	 * Instead of using this method directly, call
 	 * createAltInternalOwnCloudName($name, true)
@@ -607,9 +726,9 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * creates a unique name for internal ownCloud use for groups. Don't call it directly.
+	 * creates a unique name for internal Nextcloud use for groups. Don't call it directly.
 	 * @param string $name the display name of the object
-	 * @return string|false with with the name to use in ownCloud or false if unsuccessful.
+	 * @return string|false with with the name to use in Nextcloud or false if unsuccessful.
 	 *
 	 * Instead of using this method directly, call
 	 * createAltInternalOwnCloudName($name, false)
@@ -635,7 +754,7 @@ class Access extends LDAPUtility implements IUserTools {
 			// Check to be really sure it is unique
 			// while loop is just a precaution. If a name is not generated within
 			// 20 attempts, something else is very wrong. Avoids infinite loop.
-			if(!\OC_Group::groupExists($altName)) {
+			if(!\OC::$server->getGroupManager()->groupExists($altName)) {
 				return $altName;
 			}
 			$altName = $name . '_' . ($lastNo + $attempts);
@@ -645,10 +764,10 @@ class Access extends LDAPUtility implements IUserTools {
 	}
 
 	/**
-	 * creates a unique name for internal ownCloud use.
+	 * creates a unique name for internal Nextcloud use.
 	 * @param string $name the display name of the object
 	 * @param boolean $isUser whether name should be created for a user (true) or a group (false)
-	 * @return string|false with with the name to use in ownCloud or false if unsuccessful
+	 * @return string|false with with the name to use in Nextcloud or false if unsuccessful
 	 */
 	private function createAltInternalOwnCloudName($name, $isUser) {
 		$originalTTL = $this->connection->ldapCacheTTL;
@@ -927,7 +1046,7 @@ class Access extends LDAPUtility implements IUserTools {
 	 * @param array $sr the array containing the LDAP search resources
 	 * @param string $filter the LDAP filter for the search
 	 * @param array $base an array containing the LDAP subtree(s) that shall be searched
-	 * @param int $iFoundItems number of results in the search operation
+	 * @param int $iFoundItems number of results in the single search operation
 	 * @param int $limit maximum results to be counted
 	 * @param int $offset a starting point
 	 * @param bool $pagedSearchOK whether a paged search has been executed
@@ -956,8 +1075,11 @@ class Access extends LDAPUtility implements IUserTools {
 				$this->pagedSearchedSuccessful = true;
 			}
 		} else {
-			if(!is_null($limit)) {
-				\OCP\Util::writeLog('user_ldap', 'Paged search was not available', \OCP\Util::INFO);
+			if(!is_null($limit) && intval($this->connection->ldapPagingSize) !== 0) {
+				\OC::$server->getLogger()->debug(
+					'Paged search was not available',
+					[ 'app' => 'user_ldap' ]
+				);
 			}
 		}
 		/* ++ Fixing RHDS searches with pages with zero results ++
@@ -1045,10 +1167,10 @@ class Access extends LDAPUtility implements IUserTools {
 	 * @param bool $skipHandling
 	 * @return array with the search result
 	 */
-	private function search($filter, $base, $attr = null, $limit = null, $offset = null, $skipHandling = false) {
-		if($limit <= 0) {
-			//otherwise search will fail
-			$limit = null;
+	public function search($filter, $base, $attr = null, $limit = null, $offset = null, $skipHandling = false) {
+		$limitPerPage = intval($this->connection->ldapPagingSize);
+		if(!is_null($limit) && $limit < $limitPerPage && $limit > 0) {
+			$limitPerPage = $limit;
 		}
 
 		/* ++ Fixing RHDS searches with pages with zero results ++
@@ -1060,7 +1182,7 @@ class Access extends LDAPUtility implements IUserTools {
 		$findings = array();
 		$savedoffset = $offset;
 		do {
-			$search = $this->executeSearch($filter, $base, $attr, $limit, $offset);
+			$search = $this->executeSearch($filter, $base, $attr, $limitPerPage, $offset);
 			if($search === false) {
 				return array();
 			}
@@ -1071,26 +1193,29 @@ class Access extends LDAPUtility implements IUserTools {
 				//i.e. result do not need to be fetched, we just need the cookie
 				//thus pass 1 or any other value as $iFoundItems because it is not
 				//used
-				$this->processPagedSearchStatus($sr, $filter, $base, 1, $limit,
+				$this->processPagedSearchStatus($sr, $filter, $base, 1, $limitPerPage,
 								$offset, $pagedSearchOK,
 								$skipHandling);
 				return array();
 			}
 
+			$iFoundItems = 0;
 			foreach($sr as $res) {
 				$findings = array_merge($findings, $this->invokeLDAPMethod('getEntries', $cr, $res));
+				$iFoundItems = max($iFoundItems, $findings['count']);
+				unset($findings['count']);
 			}
 
-			$continue = $this->processPagedSearchStatus($sr, $filter, $base, $findings['count'],
-								$limit, $offset, $pagedSearchOK,
+			$continue = $this->processPagedSearchStatus($sr, $filter, $base, $iFoundItems,
+				$limitPerPage, $offset, $pagedSearchOK,
 										$skipHandling);
-			$offset += $limit;
-		} while ($continue && $pagedSearchOK && $findings['count'] < $limit);
+			$offset += $limitPerPage;
+		} while ($continue && $pagedSearchOK && ($limit === null || count($findings) < $limit));
 		// reseting offset
 		$offset = $savedoffset;
 
 		// if we're here, probably no connection resource is returned.
-		// to make ownCloud behave nicely, we simply give back an empty array.
+		// to make Nextcloud behave nicely, we simply give back an empty array.
 		if(is_null($findings)) {
 			return array();
 		}
@@ -1140,16 +1265,22 @@ class Access extends LDAPUtility implements IUserTools {
 
 	/**
 	 * @param string $name
-	 * @return bool|mixed|string
+	 * @return string
+	 * @throws \InvalidArgumentException
 	 */
 	public function sanitizeUsername($name) {
+		$name = trim($name);
+
 		if($this->connection->ldapIgnoreNamingRules) {
 			return $name;
 		}
 
-		// Transliteration
-		// latin characters to ASCII
-		$name = iconv('UTF-8', 'ASCII//TRANSLIT', $name);
+		// Transliteration to ASCII
+		$transliterated = @iconv('UTF-8', 'ASCII//TRANSLIT', $name);
+		if($transliterated !== false) {
+			// depending on system config iconv can work or not
+			$name = $transliterated;
+		}
 
 		// Replacements
 		$name = str_replace(' ', '_', $name);
@@ -1157,6 +1288,10 @@ class Access extends LDAPUtility implements IUserTools {
 		// Every remaining disallowed characters will be removed
 		$name = preg_replace('/[^a-zA-Z0-9_.@-]/u', '', $name);
 
+		if($name === '') {
+			throw new \InvalidArgumentException('provided name template for username does not contain any allowed characters');
+		}
+
 		return $name;
 	}
 
