@@ -12,6 +12,7 @@
  * @author Robin Appelman <robin@icewind.nl>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roger Szabo <roger.szabo@web.de>
+ * @author Xuanwo <xuanwo@yunify.com>
  *
  * @license AGPL-3.0
  *
@@ -42,10 +43,13 @@ use OC\ServerNotAvailableException;
  * @property string ldapUserFilter
  * @property string ldapUserDisplayName
  * @property string ldapUserDisplayName2
+ * @property boolean turnOnPasswordChange
  * @property boolean hasPagedResultSupport
  * @property string[] ldapBaseUsers
- * @property int|string ldapPagingSize holds an integer
+ * @property int|null ldapPagingSize holds an integer
  * @property bool|mixed|void ldapGroupMemberAssocAttr
+ * @property string ldapUuidUserAttribute
+ * @property string ldapUuidGroupAttribute
  */
 class Connection extends LDAPUtility {
 	private $ldapConnectionRes = null;
@@ -61,6 +65,11 @@ class Connection extends LDAPUtility {
 	 */
 	public $hasPrimaryGroups = true;
 
+	/**
+	 * @var bool runtime flag that indicates whether supported POSIX gidNumber are available
+	 */
+	public $hasGidNumber = true;
+
 	//cache handler
 	protected $cache;
 
@@ -87,7 +96,7 @@ class Connection extends LDAPUtility {
 		if($memcache->isAvailable()) {
 			$this->cache = $memcache->create();
 		}
-		$helper = new Helper();
+		$helper = new Helper(\OC::$server->getConfig());
 		$this->doNotValidate = !in_array($this->configPrefix,
 			$helper->getServerConfigurationPrefixes());
 		$this->hasPagedResultSupport =
@@ -137,7 +146,7 @@ class Connection extends LDAPUtility {
 		$this->configuration->$name = $value;
 		$after = $this->configuration->$name;
 		if($before !== $after) {
-			if(!empty($this->configID)) {
+			if ($this->configID !== '') {
 				$this->configuration->saveConfiguration();
 			}
 			$this->validateConfiguration();
@@ -199,7 +208,7 @@ class Connection extends LDAPUtility {
 		if(is_null($key)) {
 			return $prefix;
 		}
-		return $prefix.md5($key);
+		return $prefix.hash('sha256', $key);
 	}
 
 	/**
@@ -326,11 +335,6 @@ class Connection extends LDAPUtility {
 		foreach(array('ldapBaseUsers', 'ldapBaseGroups') as $keyBase) {
 			$val = $this->configuration->$keyBase;
 			if(empty($val)) {
-				$obj = strpos('Users', $keyBase) !== false ? 'Users' : 'Groups';
-				\OCP\Util::writeLog('user_ldap',
-									'Base tree for '.$obj.
-									' is empty, using Base DN',
-									\OCP\Util::INFO);
 				$this->configuration->$keyBase = $this->configuration->ldapBase;
 			}
 		}
@@ -343,7 +347,7 @@ class Connection extends LDAPUtility {
 				$this->configuration->$effectiveSetting = $uuidOverride;
 			} else {
 				$uuidAttributes = array('auto', 'entryuuid', 'nsuniqueid',
-										'objectguid', 'guid');
+										'objectguid', 'guid', 'ipauniqueid');
 				if(!in_array($this->configuration->$effectiveSetting,
 							$uuidAttributes)
 					&& (!is_null($this->configID))) {
@@ -358,8 +362,8 @@ class Connection extends LDAPUtility {
 			}
 		}
 
-		$backupPort = $this->configuration->ldapBackupPort;
-		if(empty($backupPort)) {
+		$backupPort = intval($this->configuration->ldapBackupPort);
+		if ($backupPort <= 0) {
 			$this->configuration->backupPort = $this->configuration->ldapPort;
 		}
 
@@ -427,10 +431,13 @@ class Connection extends LDAPUtility {
 		//combinations
 		$agent = $this->configuration->ldapAgentName;
 		$pwd = $this->configuration->ldapAgentPassword;
-		if((empty($agent) && !empty($pwd)) || (!empty($agent) && empty($pwd))) {
+		if (
+			($agent === ''  && $pwd !== '')
+			|| ($agent !== '' && $pwd === '')
+		) {
 			\OCP\Util::writeLog('user_ldap',
-								$errorStr.'either no password is given for the'.
-								'user agent or a password is given, but not an'.
+								$errorStr.'either no password is given for the '.
+								'user agent or a password is given, but not an '.
 								'LDAP agent.',
 				\OCP\Util::WARN);
 			$configurationOK = false;
@@ -558,16 +565,17 @@ class Connection extends LDAPUtility {
 			}
 			return $bindStatus;
 		}
+		return null;
 	}
 
 	/**
 	 * @param string $host
 	 * @param string $port
-	 * @return false|void
+	 * @return bool
 	 * @throws \OC\ServerNotAvailableException
 	 */
 	private function doConnect($host, $port) {
-		if(empty($host)) {
+		if ($host === '') {
 			return false;
 		}
 		$this->ldapConnectionRes = $this->ldap->connect($host, $port);
@@ -580,6 +588,7 @@ class Connection extends LDAPUtility {
 		} else {
 			throw new \OC\ServerNotAvailableException('Could not set required LDAP Protocol version.');
 		}
+		return true;
 	}
 
 	/**
