@@ -18,6 +18,7 @@
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Xuanwo <xuanwo@yunify.com>
  *
  * @license AGPL-3.0
  *
@@ -198,6 +199,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 	 * @param string $dnGroup
 	 * @param array|null &$seen
 	 * @return array|mixed|null
+	 * @throws \OC\ServerNotAvailableException
 	 */
 	private function _groupMembers($dnGroup, &$seen = null) {
 		if ($seen === null) {
@@ -211,27 +213,27 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 		// used extensively in cron job, caching makes sense for nested groups
 		$cacheKey = '_groupMembers'.$dnGroup;
 		$groupMembers = $this->access->connection->getFromCache($cacheKey);
-		if(!is_null($groupMembers)) {
+		if($groupMembers !== null) {
 			return $groupMembers;
 		}
 		$seen[$dnGroup] = 1;
 		$members = $this->access->readAttribute($dnGroup, $this->access->connection->ldapGroupMemberAssocAttr,
 												$this->access->connection->ldapGroupFilter);
 		if (is_array($members)) {
-			foreach ($members as $memberDN) {
-				$allMembers[$memberDN] = 1;
+			foreach ($members as $member) {
+				$allMembers[$member] = 1;
 				$nestedGroups = $this->access->connection->ldapNestedGroups;
 				if (!empty($nestedGroups)) {
-					$subMembers = $this->_groupMembers($memberDN, $seen);
+					$subMembers = $this->_groupMembers($member, $seen);
 					if ($subMembers) {
-						$allMembers = array_merge($allMembers, $subMembers);
+						$allMembers += $subMembers;
 					}
 				}
 			}
 		}
-		
-		$allMembers = array_merge($allMembers, $this->getDynamicGroupMembers($dnGroup));
-		
+
+		$allMembers += $this->getDynamicGroupMembers($dnGroup);
+
 		$this->access->connection->writeToCache($cacheKey, $allMembers);
 		return $allMembers;
 	}
@@ -263,11 +265,171 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 				$allGroups = array_merge($allGroups, $subGroups);
 			}
 		}
-		return $allGroups;	
+		return $allGroups;
 	}
 
 	/**
-	 * translates a primary group ID into an ownCloud internal name
+	 * translates a gidNumber into an ownCloud internal name
+	 * @param string $gid as given by gidNumber on POSIX LDAP
+	 * @param string $dn a DN that belongs to the same domain as the group
+	 * @return string|bool
+	 */
+	public function gidNumber2Name($gid, $dn) {
+		$cacheKey = 'gidNumberToName' . $gid;
+		$groupName = $this->access->connection->getFromCache($cacheKey);
+		if(!is_null($groupName) && isset($groupName)) {
+			return $groupName;
+		}
+
+		//we need to get the DN from LDAP
+		$filter = $this->access->combineFilterWithAnd([
+			$this->access->connection->ldapGroupFilter,
+			'objectClass=posixGroup',
+			$this->access->connection->ldapGidNumber . '=' . $gid
+		]);
+		$result = $this->access->searchGroups($filter, array('dn'), 1);
+		if(empty($result)) {
+			return false;
+		}
+		$dn = $result[0]['dn'][0];
+
+		//and now the group name
+		//NOTE once we have separate ownCloud group IDs and group names we can
+		//directly read the display name attribute instead of the DN
+		$name = $this->access->dn2groupname($dn);
+
+		$this->access->connection->writeToCache($cacheKey, $name);
+
+		return $name;
+	}
+
+	/**
+	 * returns the entry's gidNumber
+	 * @param string $dn
+	 * @param string $attribute
+	 * @return string|bool
+	 */
+	private function getEntryGidNumber($dn, $attribute) {
+		$value = $this->access->readAttribute($dn, $attribute);
+		if(is_array($value) && !empty($value)) {
+			return $value[0];
+		}
+		return false;
+	}
+
+	/**
+	 * returns the group's primary ID
+	 * @param string $dn
+	 * @return string|bool
+	 */
+	public function getGroupGidNumber($dn) {
+		return $this->getEntryGidNumber($dn, 'gidNumber');
+	}
+
+	/**
+	 * returns the user's gidNumber
+	 * @param string $dn
+	 * @return string|bool
+	 */
+	public function getUserGidNumber($dn) {
+		$gidNumber = false;
+		if($this->access->connection->hasGidNumber) {
+			$gidNumber = $this->getEntryGidNumber($dn, $this->access->connection->ldapGidNumber);
+			if($gidNumber === false) {
+				$this->access->connection->hasGidNumber = false;
+			}
+		}
+		return $gidNumber;
+	}
+
+	/**
+	 * returns a filter for a "users has specific gid" search or count operation
+	 *
+	 * @param string $groupDN
+	 * @param string $search
+	 * @return string
+	 * @throws \Exception
+	 */
+	private function prepareFilterForUsersHasGidNumber($groupDN, $search = '') {
+		$groupID = $this->getGroupGidNumber($groupDN);
+		if($groupID === false) {
+			throw new \Exception('Not a valid group');
+		}
+
+		$filterParts = [];
+		$filterParts[] = $this->access->getFilterForUserCount();
+		if ($search !== '') {
+			$filterParts[] = $this->access->getFilterPartForUserSearch($search);
+		}
+		$filterParts[] = $this->access->connection->ldapGidNumber .'=' . $groupID;
+
+		$filter = $this->access->combineFilterWithAnd($filterParts);
+
+		return $filter;
+	}
+
+	/**
+	 * returns a list of users that have the given group as gid number
+	 *
+	 * @param string $groupDN
+	 * @param string $search
+	 * @param int $limit
+	 * @param int $offset
+	 * @return string[]
+	 */
+	public function getUsersInGidNumber($groupDN, $search = '', $limit = -1, $offset = 0) {
+		try {
+			$filter = $this->prepareFilterForUsersHasGidNumber($groupDN, $search);
+			$users = $this->access->fetchListOfUsers(
+				$filter,
+				[$this->access->connection->ldapUserDisplayName, 'dn'],
+				$limit,
+				$offset
+			);
+			return $this->access->nextcloudUserNames($users);
+		} catch (\Exception $e) {
+			return [];
+		}
+	}
+
+	/**
+	 * returns the number of users that have the given group as gid number
+	 *
+	 * @param string $groupDN
+	 * @param string $search
+	 * @param int $limit
+	 * @param int $offset
+	 * @return int
+	 */
+	public function countUsersInGidNumber($groupDN, $search = '', $limit = -1, $offset = 0) {
+		try {
+			$filter = $this->prepareFilterForUsersHasGidNumber($groupDN, $search);
+			$users = $this->access->countUsers($filter, ['dn'], $limit, $offset);
+			return (int)$users;
+		} catch (\Exception $e) {
+			return 0;
+		}
+	}
+
+	/**
+	 * gets the gidNumber of a user
+	 * @param string $dn
+	 * @return string
+	 */
+	public function getUserGroupByGid($dn) {
+		$groupID = $this->getUserGidNumber($dn);
+		if($groupID !== false) {
+			$groupName = $this->gidNumber2Name($groupID, $dn);
+			if($groupName !== false) {
+				return $groupName;
+			}
+		}
+
+		return false;
+	}
+
+	/**
+	 * translates a primary group ID into an Nextcloud internal name
 	 * @param string $gid as given by primaryGroupID on AD
 	 * @param string $dn a DN that belongs to the same domain as the group
 	 * @return string|bool
@@ -296,7 +458,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 		$dn = $result[0]['dn'][0];
 
 		//and now the group name
-		//NOTE once we have separate ownCloud group IDs and group names we can
+		//NOTE once we have separate Nextcloud group IDs and group names we can
 		//directly read the display name attribute instead of the DN
 		$name = $this->access->dn2groupname($dn);
 
@@ -360,7 +522,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 
 		$filterParts = [];
 		$filterParts[] = $this->access->getFilterForUserCount();
-		if(!empty($search)) {
+		if ($search !== '') {
 			$filterParts[] = $this->access->getFilterPartForUserSearch($search);
 		}
 		$filterParts[] = 'primaryGroupID=' . $groupID;
@@ -388,7 +550,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 				$limit,
 				$offset
 			);
-			return $this->access->ownCloudUserNames($users);
+			return $this->access->nextcloudUserNames($users);
 		} catch (\Exception $e) {
 			return array();
 		}
@@ -457,6 +619,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 
 		$groups = [];
 		$primaryGroup = $this->getUserPrimaryGroup($userDN);
+		$gidGroupName = $this->getUserGroupByGid($userDN);
 
 		$dynamicGroupMemberURL = strtolower($this->access->connection->ldapDynamicGroupMemberURL);
 
@@ -496,9 +659,11 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 
 		// if possible, read out membership via memberOf. It's far faster than
 		// performing a search, which still is a fallback later.
+		// memberof doesn't support memberuid, so skip it here.
 		if(intval($this->access->connection->hasMemberOfFilterSupport) === 1
 			&& intval($this->access->connection->useMemberOfToDetectMembership) === 1
-		) {
+		    && strtolower($this->access->connection->ldapGroupMemberAssocAttr) !== 'memberuid'
+		    ) {
 			$groupDNs = $this->_getGroupDNsFromMemberOf($userDN);
 			if (is_array($groupDNs)) {
 				foreach ($groupDNs as $dn) {
@@ -510,10 +675,13 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 					}
 				}
 			}
-			
+
 			if($primaryGroup !== false) {
 				$groups[] = $primaryGroup;
 			}
+			if($gidGroupName !== false) {
+				$groups[] = $gidGroupName;
+			}
 			$this->access->connection->writeToCache($cacheKey, $groups);
 			return $groups;
 		}
@@ -539,7 +707,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 			$groups = array_merge($groups, $this->cachedGroupsByMember[$uid]);
 		} else {
 			$groupsByMember = array_values($this->getGroupsByMember($uid));
-			$groupsByMember = $this->access->ownCloudGroupNames($groupsByMember);
+			$groupsByMember = $this->access->nextcloudGroupNames($groupsByMember);
 			$this->cachedGroupsByMember[$uid] = $groupsByMember;
 			$groups = array_merge($groups, $groupsByMember);
 		}
@@ -547,6 +715,9 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 		if($primaryGroup !== false) {
 			$groups[] = $primaryGroup;
 		}
+		if($gidGroupName !== false) {
+			$groups[] = $gidGroupName;
+		}
 
 		$groups = array_unique($groups, SORT_LOCALE_STRING);
 		$this->access->connection->writeToCache($cacheKey, $groups);
@@ -634,11 +805,12 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 		}
 
 		$primaryUsers = $this->getUsersInPrimaryGroup($groupDN, $search, $limit, $offset);
+		$posixGroupUsers = $this->getUsersInGidNumber($groupDN, $search, $limit, $offset);
 		$members = array_keys($this->_groupMembers($groupDN));
-		if(!$members && empty($primaryUsers)) {
+		if(!$members && empty($posixGroupUsers) && empty($primaryUsers)) {
 			//in case users could not be retrieved, return empty result set
-			$this->access->connection->writeToCache($cacheKey, array());
-			return array();
+			$this->access->connection->writeToCache($cacheKey, []);
+			return [];
 		}
 
 		$groupUsers = array();
@@ -658,7 +830,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 				$groupUsers[] = $this->access->dn2username($ldap_users[0]['dn'][0]);
 			} else {
 				//we got DNs, check if we need to filter by search or we can give back all of them
-				if(!empty($search)) {
+				if ($search !== '') {
 					if(!$this->access->readAttribute($member,
 						$this->access->connection->ldapUserDisplayName,
 						$this->access->getFilterPartForUserSearch($search))) {
@@ -672,12 +844,11 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 			}
 		}
 
-		$groupUsers = array_unique(array_merge($groupUsers, $primaryUsers));
+		$groupUsers = array_unique(array_merge($groupUsers, $primaryUsers, $posixGroupUsers));
 		natsort($groupUsers);
 		$this->access->connection->writeToCache('usersInGroup-'.$gid.'-'.$search, $groupUsers);
 		$groupUsers = array_slice($groupUsers, $offset, $limit);
 
-
 		$this->access->connection->writeToCache($cacheKey, $groupUsers);
 
 		return $groupUsers;
@@ -714,7 +885,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 			return false;
 		}
 
-		if(empty($search)) {
+		if ($search === '') {
 			$groupUsers = count($members) + $primaryUserCount;
 			$this->access->connection->writeToCache($cacheKey, $groupUsers);
 			return $groupUsers;
@@ -802,7 +973,7 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 				array($this->access->connection->ldapGroupDisplayName, 'dn'),
 				$limit,
 				$offset);
-		$ldap_groups = $this->access->ownCloudGroupNames($ldap_groups);
+		$ldap_groups = $this->access->nextcloudGroupNames($ldap_groups);
 
 		$this->access->connection->writeToCache($cacheKey, $ldap_groups);
 		return $ldap_groups;
@@ -826,9 +997,8 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 			return array();
 		}
 		$search = $this->access->escapeFilterPart($search, true);
-		$pagingSize = $this->access->connection->ldapPagingSize;
-		if ((! $this->access->connection->hasPagedResultSupport)
-		   	|| empty($pagingSize)) {
+		$pagingSize = intval($this->access->connection->ldapPagingSize);
+		if (!$this->access->connection->hasPagedResultSupport || $pagingSize <= 0) {
 			return $this->getGroupsChunk($search, $limit, $offset);
 		}
 		$maxGroups = 100000; // limit max results (just for safety reasons)
@@ -903,4 +1073,12 @@ class Group_LDAP extends BackendUtility implements \OCP\GroupInterface {
 	public function implementsActions($actions) {
 		return (bool)(\OC\Group\Backend::COUNT_USERS & $actions);
 	}
+
+	/**
+	 * Return access for LDAP interaction.
+	 * @return Access instance of Access for LDAP interaction
+	 */
+	public function getLDAPAccess() {
+		return $this->access;
+	}
 }
