@@ -54,6 +54,10 @@ class OC_Image implements \OCP\IImage {
 	private $fileInfo;
 	/** @var \OCP\ILogger */
 	private $logger;
+	/** @var \OCP\IConfig */
+	private $config;
+	/** @var array */
+	private $exif;
 
 	/**
 	 * Get mime type for an image file.
@@ -77,23 +81,23 @@ class OC_Image implements \OCP\IImage {
 	 * @param resource|string $imageRef The path to a local file, a base64 encoded string or a resource created by
 	 * an imagecreate* function.
 	 * @param \OCP\ILogger $logger
+	 * @param \OCP\IConfig $config
 	 */
-	public function __construct($imageRef = null, $logger = null) {
+	public function __construct($imageRef = null, \OCP\ILogger $logger = null, \OCP\IConfig $config = null) {
 		$this->logger = $logger;
-		if (is_null($logger)) {
+		if ($logger === null) {
 			$this->logger = \OC::$server->getLogger();
 		}
-
-		if (!extension_loaded('gd') || !function_exists('gd_info')) {
-			$this->logger->error(__METHOD__ . '(): GD module not installed', array('app' => 'core'));
-			return false;
+		$this->config = $config;
+		if ($config === null) {
+			$this->config = \OC::$server->getConfig();
 		}
 
 		if (\OC_Util::fileInfoLoaded()) {
 			$this->fileInfo = new finfo(FILEINFO_MIME_TYPE);
 		}
 
-		if (!is_null($imageRef)) {
+		if ($imageRef !== null) {
 			$this->load($imageRef);
 		}
 	}
@@ -208,11 +212,13 @@ class OC_Image implements \OCP\IImage {
 		if ($mimeType === null) {
 			$mimeType = $this->mimeType();
 		}
-		if ($filePath === null && $this->filePath === null) {
-			$this->logger->error(__METHOD__ . '(): called with no path.', array('app' => 'core'));
-			return false;
-		} elseif ($filePath === null && $this->filePath !== null) {
-			$filePath = $this->filePath;
+		if ($filePath === null) {
+			if ($this->filePath === null) {
+				$this->logger->error(__METHOD__ . '(): called with no path.', array('app' => 'core'));
+				return false;
+			} else {
+				$filePath = $this->filePath;
+			}
 		}
 		return $this->_output($filePath, $mimeType);
 	}
@@ -227,12 +233,14 @@ class OC_Image implements \OCP\IImage {
 	 */
 	private function _output($filePath = null, $mimeType = null) {
 		if ($filePath) {
-			if (!file_exists(dirname($filePath)))
+			if (!file_exists(dirname($filePath))) {
 				mkdir(dirname($filePath), 0777, true);
-			if (!is_writable(dirname($filePath))) {
+			}
+			$isWritable = is_writable(dirname($filePath));
+			if (!$isWritable) {
 				$this->logger->error(__METHOD__ . '(): Directory \'' . dirname($filePath) . '\' is not writable.', array('app' => 'core'));
 				return false;
-			} elseif (is_writable(dirname($filePath)) && file_exists($filePath) && !is_writable($filePath)) {
+			} elseif ($isWritable && file_exists($filePath) && !is_writable($filePath)) {
 				$this->logger->error(__METHOD__ . '(): File \'' . $filePath . '\' is not writable.', array('app' => 'core'));
 				return false;
 			}
@@ -270,7 +278,7 @@ class OC_Image implements \OCP\IImage {
 				$retVal = imagegif($this->resource, $filePath);
 				break;
 			case IMAGETYPE_JPEG:
-				$retVal = imagejpeg($this->resource, $filePath);
+				$retVal = imagejpeg($this->resource, $filePath, $this->getJpegQuality());
 				break;
 			case IMAGETYPE_PNG:
 				$retVal = imagepng($this->resource, $filePath);
@@ -309,6 +317,25 @@ class OC_Image implements \OCP\IImage {
 		return $this->resource;
 	}
 
+	/**
+	 * @return string Returns the mimetype of the data. Returns the empty string
+	 * if the data is not valid.
+	 */
+	public function dataMimeType() {
+		if (!$this->valid()) {
+			return '';
+		}
+
+		switch ($this->mimeType) {
+			case 'image/png':
+			case 'image/jpeg':
+			case 'image/gif':
+				return $this->mimeType;
+			default:
+				return 'image/png';
+		}
+	}
+
 	/**
 	 * @return null|string Returns the raw image data.
 	 */
@@ -322,7 +349,12 @@ class OC_Image implements \OCP\IImage {
 				$res = imagepng($this->resource);
 				break;
 			case "image/jpeg":
-				$res = imagejpeg($this->resource);
+				$quality = $this->getJpegQuality();
+				if ($quality !== null) {
+					$res = imagejpeg($this->resource, null, $quality);
+				} else {
+					$res = imagejpeg($this->resource);
+				}
 				break;
 			case "image/gif":
 				$res = imagegif($this->resource);
@@ -341,10 +373,21 @@ class OC_Image implements \OCP\IImage {
 	/**
 	 * @return string - base64 encoded, which is suitable for embedding in a VCard.
 	 */
-	function __toString() {
+	public function __toString() {
 		return base64_encode($this->data());
 	}
 
+	/**
+	 * @return int|null
+	 */
+	protected function getJpegQuality() {
+		$quality = $this->config->getAppValue('preview', 'jpeg_quality', 90);
+		if ($quality !== null) {
+			$quality = min(100, max(10, (int) $quality));
+		}
+		return $quality;
+	}
+
 	/**
 	 * (I'm open for suggestions on better method name ;)
 	 * Get the orientation based on EXIF data.
@@ -352,6 +395,10 @@ class OC_Image implements \OCP\IImage {
 	 * @return int The orientation or -1 if no EXIF data is available.
 	 */
 	public function getOrientation() {
+		if ($this->exif !== null) {
+			return $this->exif['Orientation'];
+		}
+
 		if ($this->imageType !== IMAGETYPE_JPEG) {
 			$this->logger->debug('OC_Image->fixOrientation() Image is not a JPEG.', array('app' => 'core'));
 			return -1;
@@ -375,9 +422,30 @@ class OC_Image implements \OCP\IImage {
 		if (!isset($exif['Orientation'])) {
 			return -1;
 		}
+		$this->exif = $exif;
 		return $exif['Orientation'];
 	}
 
+	public function readExif($data) {
+		if (!is_callable('exif_read_data')) {
+			$this->logger->debug('OC_Image->fixOrientation() Exif module not enabled.', array('app' => 'core'));
+			return;
+		}
+		if (!$this->valid()) {
+			$this->logger->debug('OC_Image->fixOrientation() No image loaded.', array('app' => 'core'));
+			return;
+		}
+
+		$exif = @exif_read_data('data://image/jpeg;base64,' . base64_encode($data));
+		if (!$exif) {
+			return;
+		}
+		if (!isset($exif['Orientation'])) {
+			return;
+		}
+		$this->exif = $exif;
+	}
+
 	/**
 	 * (I'm open for suggestions on better method name ;)
 	 * Fixes orientation based on EXIF data.
@@ -456,7 +524,7 @@ class OC_Image implements \OCP\IImage {
 	 */
 	public function load($imageRef) {
 		if (is_resource($imageRef)) {
-			if (get_resource_type($imageRef) == 'gd') {
+			if (get_resource_type($imageRef) === 'gd') {
 				$this->resource = $imageRef;
 				return $this->resource;
 			} elseif (in_array(get_resource_type($imageRef), array('file', 'stream'))) {
@@ -513,14 +581,18 @@ class OC_Image implements \OCP\IImage {
 				break;
 			case IMAGETYPE_JPEG:
 				if (imagetypes() & IMG_JPG) {
-					$this->resource = imagecreatefromjpeg($imagePath);
+					if (getimagesize($imagePath) !== false) {
+						$this->resource = @imagecreatefromjpeg($imagePath);
+					} else {
+						$this->logger->debug('OC_Image->loadFromFile, JPG image not valid: ' . $imagePath, array('app' => 'core'));
+					}
 				} else {
 					$this->logger->debug('OC_Image->loadFromFile, JPG images not supported: ' . $imagePath, array('app' => 'core'));
 				}
 				break;
 			case IMAGETYPE_PNG:
 				if (imagetypes() & IMG_PNG) {
-					$this->resource = imagecreatefrompng($imagePath);
+					$this->resource = @imagecreatefrompng($imagePath);
 					// Preserve transparency
 					imagealphablending($this->resource, true);
 					imagesavealpha($this->resource, true);
@@ -530,14 +602,14 @@ class OC_Image implements \OCP\IImage {
 				break;
 			case IMAGETYPE_XBM:
 				if (imagetypes() & IMG_XPM) {
-					$this->resource = imagecreatefromxbm($imagePath);
+					$this->resource = @imagecreatefromxbm($imagePath);
 				} else {
 					$this->logger->debug('OC_Image->loadFromFile, XBM/XPM images not supported: ' . $imagePath, array('app' => 'core'));
 				}
 				break;
 			case IMAGETYPE_WBMP:
 				if (imagetypes() & IMG_WBMP) {
-					$this->resource = imagecreatefromwbmp($imagePath);
+					$this->resource = @imagecreatefromwbmp($imagePath);
 				} else {
 					$this->logger->debug('OC_Image->loadFromFile, WBMP images not supported: ' . $imagePath, array('app' => 'core'));
 				}
@@ -725,7 +797,7 @@ class OC_Image implements \OCP\IImage {
 							$this->logger->warning($error, array('app' => 'core'));
 							return $im;
 						}
-						$color = unpack('V', $part . $vide);
+						$color = @unpack('V', $part . $vide);
 						break;
 					case 16:
 						if (!($part = substr($data, $p, 2))) {
@@ -733,20 +805,20 @@ class OC_Image implements \OCP\IImage {
 							$this->logger->warning($error, array('app' => 'core'));
 							return $im;
 						}
-						$color = unpack('v', $part);
+						$color = @unpack('v', $part);
 						$color[1] = (($color[1] & 0xf800) >> 8) * 65536 + (($color[1] & 0x07e0) >> 3) * 256 + (($color[1] & 0x001f) << 3);
 						break;
 					case 8:
-						$color = unpack('n', $vide . substr($data, $p, 1));
-						$color[1] = $palette[$color[1] + 1];
+						$color = @unpack('n', $vide . substr($data, $p, 1));
+						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					case 4:
-						$color = unpack('n', $vide . substr($data, floor($p), 1));
+						$color = @unpack('n', $vide . substr($data, floor($p), 1));
 						$color[1] = ($p * 2) % 2 == 0 ? $color[1] >> 4 : $color[1] & 0x0F;
-						$color[1] = $palette[$color[1] + 1];
+						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					case 1:
-						$color = unpack('n', $vide . substr($data, floor($p), 1));
+						$color = @unpack('n', $vide . substr($data, floor($p), 1));
 						switch (($p * 8) % 8) {
 							case 0:
 								$color[1] = $color[1] >> 7;
@@ -773,7 +845,7 @@ class OC_Image implements \OCP\IImage {
 								$color[1] = ($color[1] & 0x1);
 								break;
 						}
-						$color[1] = $palette[$color[1] + 1];
+						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					default:
 						fclose($fh);
@@ -802,8 +874,8 @@ class OC_Image implements \OCP\IImage {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
 		}
-		$widthOrig = imageSX($this->resource);
-		$heightOrig = imageSY($this->resource);
+		$widthOrig = imagesx($this->resource);
+		$heightOrig = imagesy($this->resource);
 		$ratioOrig = $widthOrig / $heightOrig;
 
 		if ($ratioOrig > 1) {
@@ -828,8 +900,8 @@ class OC_Image implements \OCP\IImage {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
 		}
-		$widthOrig = imageSX($this->resource);
-		$heightOrig = imageSY($this->resource);
+		$widthOrig = imagesx($this->resource);
+		$heightOrig = imagesy($this->resource);
 		$process = imagecreatetruecolor($width, $height);
 
 		if ($process == false) {
@@ -867,8 +939,8 @@ class OC_Image implements \OCP\IImage {
 			$this->logger->error('OC_Image->centerCrop, No image loaded', array('app' => 'core'));
 			return false;
 		}
-		$widthOrig = imageSX($this->resource);
-		$heightOrig = imageSY($this->resource);
+		$widthOrig = imagesx($this->resource);
+		$heightOrig = imagesy($this->resource);
 		if ($widthOrig === $heightOrig and $size == 0) {
 			return true;
 		}
@@ -967,8 +1039,8 @@ class OC_Image implements \OCP\IImage {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
 		}
-		$widthOrig = imageSX($this->resource);
-		$heightOrig = imageSY($this->resource);
+		$widthOrig = imagesx($this->resource);
+		$heightOrig = imagesy($this->resource);
 		$ratio = $widthOrig / $heightOrig;
 
 		$newWidth = min($maxWidth, $ratio * $maxHeight);
@@ -990,8 +1062,8 @@ class OC_Image implements \OCP\IImage {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
 		}
-		$widthOrig = imageSX($this->resource);
-		$heightOrig = imageSY($this->resource);
+		$widthOrig = imagesx($this->resource);
+		$heightOrig = imagesy($this->resource);
 
 		if ($widthOrig > $maxWidth || $heightOrig > $maxHeight) {
 			return $this->fitIn($maxWidth, $maxHeight);
@@ -1024,6 +1096,7 @@ if (!function_exists('imagebmp')) {
 	 * @link http://www.programmierer-forum.de/imagebmp-gute-funktion-gefunden-t143716.htm
 	 * @author mgutt <marc@gutt.it>
 	 * @version 1.00
+	 * @param resource $im
 	 * @param string $fileName [optional] <p>The path to save the file to.</p>
 	 * @param int $bit [optional] <p>Bit depth, (default is 24).</p>
 	 * @param int $compression [optional]
