@@ -27,8 +27,6 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
     "Federated Cloud Sharing" : "Federated Cloud Sharing",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilise %s %s, qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %s ne fonctionneront pas correctement.",
-    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
-    "Migration Completed" : "Migration terminée",
     "Group already exists." : "Ce groupe existe déjà.",
     "Unable to add group." : "Impossible d'ajouter le groupe.",
     "Unable to delete group." : "Impossible de supprimer le groupe.",
@@ -77,11 +75,10 @@ OC.L10N.register(
     "Set your password" : "Saisissez votre mot de passe",
     "Go to %s" : "Aller à %s",
     "Install Client" : "Installer le Client",
+    "Logged in user must be a subadmin" : "L'utilisateur connecté doit être un sous-admin",
     "Password confirmation is required" : "Confirmation par mot de passe est requise",
     "Couldn't remove app." : "Impossible de supprimer l'application.",
     "Couldn't update app." : "Impossible de mettre à jour l'application",
-    "Are you really sure you want add {domain} as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter {domain} comme domaine de confiance ?",
-    "Add trusted domain" : "Ajouter un domaine de confiance",
     "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
     "Migration started …" : "Migration démarrée...",
     "Not saved" : "Non sauvegardé",
@@ -104,15 +101,15 @@ OC.L10N.register(
     "Error: This app can not be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car cela rend le serveur instable.",
     "Error: Could not disable broken app" : "Erreur : Impossible de désactiver l’application cassé",
     "Error while disabling broken app" : "Erreur lors de la désactivation de l'application cassé  .",
-    "No app updates available" : "Aucune mise à jour de l'application n'est disponible",
-    "Updating...." : "Mise à jour...",
-    "Error while updating app" : "Erreur lors de la mise à jour de l'application",
+    "App up to date" : "Application à jour",
+    "Updating …" : "Mise à jour en cours...",
+    "Could not update app" : "Impossible de mettre à jour l'application",
     "Updated" : "Mise à jour terminée",
     "Removing …" : "Suppression...",
-    "Error while removing app" : "Erreur lors de la suppression de l'application",
+    "Could not remove app" : "Impossible de supprimer l'application.",
     "Remove" : "Supprimer",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
-    "App update" : "Mise à jour",
+    "App update" : "Mise à jour de l'application",
     "Approved" : "Approuvée",
     "Experimental" : "Expérimentale",
     "No apps found for {query}" : "Aucune application trouvée pour {query}",
@@ -161,6 +158,7 @@ OC.L10N.register(
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe de forte sécurité",
     "Groups" : "Groupes",
+    "Unable to retrieve the group list" : "Impossible de récupérer la liste du groupe",
     "Unable to delete {objName}" : "Impossible de supprimer {objName}",
     "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
     "A valid group name must be provided" : "Vous devez indiquer un nom de groupe valide",
@@ -181,8 +179,6 @@ OC.L10N.register(
     "Error while changing status of {user}" : "Erreur lors du changement de statut de {user}",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Error creating user: {message}" : "Erreur a la création d'un utilisateur : {message}",
-    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
-    "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
     "Developer documentation" : "Documentation pour développeurs",
     "View in store" : "Afficher dans le magasin d'application",
     "Limit to groups" : "Limiter aux groupes",
@@ -297,13 +293,13 @@ OC.L10N.register(
     "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués.",
     "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Afficher les conditions d'utilisation sur la page publique de téléversement (seulement lorsque la liste des fichiers est masquée).",
     "This text will be shown on the public link upload page when the file list is hidden." : "Ce texte sera affiché sur la page publique de téléversement lorsque la liste des fichiers est masquée.",
+    "Default share permissions" : "Autorisations de partage par défaut",
     "Tips & tricks" : "Trucs et astuces",
     "There are a lot of features and config switches available to optimally customize and use this instance. Here are some pointers for more information." : "Il y a beaucoup de fonctionnalités et de choix de configurations disponibles qui permettent de manière optimale de customiser et d'utiliser cette instance. Voici quelques liens pour en savoir plus.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite est actuellement utilisé comme système de gestion de base de données. Pour des installations plus volumineuses, nous vous recommandons de migrer vers un autre système de gestion de base de données.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "C'est particulièrement recommandé lorsque l'on utilise un client bureau pour la synchronisation des fichiers.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>.",
     "How to do backups" : "Comment faire des sauvegardes",
-    "Advanced monitoring" : "Surveillance avancée",
     "Performance tuning" : "Ajustement des performances",
     "Improving the config.php" : "Amélioration du config.php ",
     "Theming" : "Personnalisation de l'apparence",
@@ -321,6 +317,7 @@ OC.L10N.register(
     "Picture provided by original account" : "Photo fournie par le compte original",
     "Cancel" : "Annuler",
     "Choose as profile picture" : "Définir comme image de profil",
+    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
     "Full name" : "Nom complet",
     "No display name set" : "Aucun nom d'affichage configuré",
     "Email" : "Adresse e-mail",
@@ -336,7 +333,6 @@ OC.L10N.register(
     "Link https://…" : "Lien https://…",
     "Twitter" : "Twitter",
     "Twitter handle @…" : "Pseudo Twitter @...",
-    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
     "Language" : "Langue",
     "Help translate" : "Aidez à traduire",
     "Password" : "Mot de passe",
@@ -362,13 +358,8 @@ OC.L10N.register(
     "Show storage location" : "Afficher l'emplacement du stockage",
     "Show user backend" : "Montrer la source de l'identifiant",
     "Show last login" : "Montrer la dernière connexion",
-    "Show email address" : "Afficher l'adresse e-mail",
-    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
     "When the password of a new user is left empty, an activation email with a link to set the password is sent." : "Quand le mot de passe d'un nouvel utilisateur est laissé vide, un mail d'activation avec un lien pour configurer le mot de passe est envoyé.",
-    "E-Mail" : "E-Mail",
-    "Create" : "Créer",
-    "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
-    "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
+    "Add user" : "Ajouter un utilisateur",
     "Everyone" : "Tout le monde",
     "Admins" : "Administrateurs",
     "Disabled" : "Désactivé",
@@ -377,83 +368,64 @@ OC.L10N.register(
     "Unlimited" : "Illimité",
     "Other" : "Autre",
     "Group admin for" : "Administrateur de groupe pour",
+    "Recovery password" : "Mot de passe de récupération ",
     "Quota" : "Quota",
     "Storage location" : "Emplacement du stockage",
     "User backend" : "Retour utilisateur",
     "Last login" : "Dernière connexion",
+    "E-Mail" : "E-Mail",
+    "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
+    "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
     "change full name" : "Modifier le nom complet",
     "set new password" : "Changer le mot de passe",
     "change email address" : "changer l'adresse e-mail",
     "Default" : "Défaut",
-    "Enabled" : "Activées",
-    "Not enabled" : "Désactivées",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
-    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour avec succès.",
-    "test email settings" : "Test des paramètres e-mail",
-    "Invalid request" : "Requête non valide",
-    "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
-    "Unable to add user to group %s" : "Impossible d'ajouter l'utilisateur au groupe %s",
-    "Unable to remove user from group %s" : "Impossible de supprimer l'utilisateur du groupe %s",
-    "Sending..." : "Envoi en cours…",
+    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
+    "Migration Completed" : "Migration terminée",
+    "Are you really sure you want add {domain} as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter {domain} comme domaine de confiance ?",
+    "Add trusted domain" : "Ajouter un domaine de confiance",
     "_You have %n app update pending_::_You have %n app updates pending_" : ["Vous avez %n application en attente de mise à jour","Vous avez %n applications en attente de mise à jour"],
-    "Uninstalling ...." : "Désinstallation...",
-    "Error while uninstalling app" : "Erreur lors de la désinstallation de l'application",
-    "Uninstall" : "Désinstaller",
+    "Updating...." : "Mise à jour en cours...",
+    "Error while updating app" : "Erreur lors de la mise à jour de l'application",
+    "Error while removing app" : "Erreur lors de la suppression de l'application",
+    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
+    "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
     "__language_name__" : "Français",
+    "Verifying" : "Vérification en cours",
     "Personal info" : "Informations personnelles",
-    "Sessions" : "Sessions",
-    "App passwords" : "Mots de passe de l'application",
     "Sync clients" : "Clients de synchronisation",
-    "This is used for sending out notifications." : "Ceci est utilisé pour l'envoi des notifications.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance effectue quelques vérifications automatiques. Veuillez consulter la section Trucs & Astuces, ainsi que la documentation, pour de plus amples informations.",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
     "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous recommandons de mettre %1$s à jour.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous vous recommandons de mettre %1$s à jour.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection du type MIME.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Activez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
     "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres locaux suivants : %s",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements des <a href=\"%s\">logs</a> de cette instance.",
-    "Cron" : "Cron",
-    "Last cron job execution: %s." : "Dernière tâche cron exécutée : %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Dernière tâche cron exécutée : %s. Quelque chose s'est mal passé.",
-    "Cron was not executed yet!" : "Le cron n'a pas encore été exécuté !",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Utilisez un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements dans les <a href=\"%s\">journaux</a>.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php est enregistré à un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP.",
     "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Pour l'exécuter, vous devez avoir l'extension PHP posix. Regarder la {linkstart}documentation PHP{linkend} pour plus de détails.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée,  les noms complets doivent être indiqués.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>.",
-    "Uninstall app" : "Désinstaller l'application",
-    "Hey there,<br><br>just letting you know that you now have a %s account.<br><br>Your username: <strong>%s</strong><br>Access it: <strong><a href=\"%s\">%s</a></strong><br><br>" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : <strong>%s</strong><br>Visitez votre compte : <strong><a href=\"%s\">%s</a></strong><br><br>",
-    "Cheers!" : "À bientôt !",
-    "Hey there,\n\njust letting you know that you now have a %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,\n\nUn compte %s a été créé pour vous.\n\nVotre nom d'utilisateur : %s\nVisitez votre compte : %s\n\n",
-    "For password recovery and notifications" : "Pour la récupération de mot de passe et les notifications",
-    "Your website" : "Votre site web",
-    "Your Twitter handle" : "Votre pseudo Twitter",
-    "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
+    "Get the apps to sync your files" : "Obtenez les applications pour synchroniser vos fichiers",
     "Desktop client" : "Client de bureau",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
-    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Si vous voulez apporter votre appui au projet {contributeopen}joignez-vous à son développement{linkclose} ou {contributeopen}passez le mot{linkclose}!",
-    "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
-    "Passcodes that give an app or device permissions to access your account." : "Codes de sécurité autorisant une application ou un appareil à accéder à votre compte.",
-    "Name" : "Nom",
-    "Follow us on Google Plus!" : "Suiviez-nous sur Google Plus!",
-    "Like our facebook page!" : "Aimez notre page facebook!",
-    "Subscribe to our twitter channel!" : "Enregistrez notre page twitter!",
-    "Subscribe to our news feed!" : "Abonnez-vous à notre flux d'actualités!",
-    "Subscribe to our newsletter!" : "Abonnez-vous à notre newsletter!",
-    "Show last log in" : "Montrer la dernière connexion",
-    "Group name" : "Nom de groupe",
-    "Verifying" : "Vérification en cours",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance Nextcloud effectue quelques vérifications automatiques. Pour de plus amples informations, veuillez consulter la section Trucs & Astuces, ainsi que la documentation Nextcloud.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection du type MIME.",
-    "Web, desktop, mobile clients and app specific passwords that currently have access to your account." : "Clients web, desktop, mobiles et mots de passe spécifiques d'application qui ont actuellement accès à votre compte.",
+    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Si vous voulez soutenir le projet {contributeopen}rejoindre son développement{linkclose} ou {contributeopen}passez le mot{linkclose}!",
+    "Show First Run Wizard again" : "Ré-afficher l'assistant de premier démarrage",
+    "Web, desktop, mobile clients and app specific passwords that currently have access to your account." : "Les clients web, de bureau et mobiles ainsi que les mots de passe spécifiques d'application qui ont accès actuellement à votre compte.",
+    "App passwords" : "Mots de passe d'application",
     "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "Ici vous pouvez générer des mots de passe individuels pour les applications pour éviter de communiquer votre mot de passe. Vous pouvez aussi les révoquer individuellement.",
     "Follow us on Google+!" : "Suivez-nous sur Google+ !",
+    "Like our facebook page!" : "Aimez notre page Facebook !",
     "Follow us on Twitter!" : "Suivez-nous sur Twitter !",
-    "Check out our blog!" : "Découvrez notre blog !"
+    "Check out our blog!" : "Découvrez notre blog !",
+    "Subscribe to our newsletter!" : "Abonnez-vous à notre newsletter!",
+    "Show email address" : "Afficher l'adresse e-mail",
+    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
+    "Create" : "Créer",
+    "Group name" : "Nom du groupe"
 },
 "nplurals=2; plural=(n > 1);");
